==> mapmyindia_gl-0.2.0.tar.gz: lib/src/api/place_detail/place_detail_legacy_response.dart <==
part of mapmyindia_gl;

@deprecated
class PlaceDetailLegacyResponse {
  List<PlaceDetailLegacyResult>? results;
  int? responseCode;
  String? version;

  static PlaceDetailLegacyResponse fromMap(Map<String, dynamic> map) {
    PlaceDetailLegacyResponse placeResponseBean = PlaceDetailLegacyResponse();
    if (map.containsKey('results')) {
      List<dynamic> results = map['results'] as List<dynamic>;
      placeResponseBean.results = List.generate(results.length, (index) {
        return PlaceDetailLegacyResult.fromMap(results[index] as Map<String, dynamic>);
      });
    }
    placeResponseBean.responseCode = map['responseCode'];
    placeResponseBean.version = map['version'];
    return placeResponseBean;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> map = <String, dynamic>{};


    void addIfNonNull(String fieldName, dynamic value) {
      if (value != null) {
        map[fieldName] = value;
      }
    }
    if (this.results != null) {
      map['results'] = List.generate(this.results!.length, (index) {
        return this.results![index].toJson();
      });
    }

    addIfNonNull('responseCode', responseCode);
    addIfNonNull('version', version);
    return map;
  }
}

@deprecated
class PlaceDetailLegacyResult {
  String? area;
  String? city;
  String? district;
  String? formattedAddress;
  String? houseName;
  String? houseNumber;
  String? lat;
  String? lng;
  String? locality;
  String? pincode;
  String? poi;
  String? poiDist;
  String? state;
  String? street;
  String? streetDist;
  String? subDistrict;
  String? subLocality;
  String? subSubLocality;
  String? village;
  String? placeId;

  static PlaceDetailLegacyResult fromMap(Map<String, dynamic> map) {
    PlaceDetailLegacyResult resultsBean = PlaceDetailLegacyResult();
    resultsBean.area = map['area'];
    resultsBean.city = map['city'];
    resultsBean.district = map['district'];
    resultsBean.formattedAddress = map['formatted_address'];
    resultsBean.houseName = map['houseName'];
    resultsBean.houseNumber = map['houseNumber'];
    resultsBean.lat = map['lat'];
    resultsBean.lng = map['lng'];
    resultsBean.locality = map['locality'];
    resultsBean.pincode = map['pincode'];
    resultsBean.poi = map['poi'];
    resultsBean.poiDist = map['poi_dist'];
    resultsBean.state = map['state'];
    resultsBean.street = map['street'];
    resultsBean.streetDist = map['street_dist'];
    resultsBean.subDistrict = map['subDistrict'];
    resultsBean.subLocality = map['subLocality'];
    resultsBean.subSubLocality = map['subSubLocality'];
    resultsBean.village = map['village'];
    resultsBean.placeId = map['place_id'];
    return resultsBean;
  }

  Map toJson() =>
      {
        "area": area,
        "city": city,
        "district": district,
        "formatted_address": formattedAddress,
        "houseName": houseName,
        "houseNumber": houseNumber,
        "lat": lat,
        "lng": lng,
        "locality": locality,
        "pincode": pincode,
        "poi": poi,
        "poi_dist": poiDist,
        "state": state,
        "street": street,
        "street_dist": streetDist,
        "subDistrict": subDistrict,
        "subLocality": subLocality,
        "subSubLocality": subSubLocality,
        "village": village,
        "place_id": placeId,
      };
}

==> mapmyindia_gl-0.3.2.tar.gz: lib/src/api/place_detail/place_detail_legacy_response.dart <==
part of mapmyindia_gl;

@deprecated
class PlaceDetailLegacyResponse {
  List<PlaceDetailLegacyResult>? results;
  int? responseCode;
  String? version;

  static PlaceDetailLegacyResponse fromMap(Map<String, dynamic> map) {
    PlaceDetailLegacyResponse placeResponseBean = PlaceDetailLegacyResponse();
    if (map.containsKey('results')) {
      List<dynamic> results = map['results'] as List<dynamic>;
      placeResponseBean.results = List.generate(results.length, (index) {
        return PlaceDetailLegacyResult.fromMap(
            results[index] as Map<String, dynamic>);
      });
    }
    placeResponseBean.responseCode = map['responseCode'];
    placeResponseBean.version = map['version'];
    return placeResponseBean;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> map = <String, dynamic>{};

    void addIfNonNull(String fieldName, dynamic value) {
      if (value != null) {
        map[fieldName] = value;
      }
    }

    if (this.results != null) {
      map['results'] = List.generate(this.results!.length, (index) {
        return this.results![index].toJson();
      });
    }

    addIfNonNull('responseCode', responseCode);
    addIfNonNull('version', version);
    return map;
  }
}

@deprecated
class PlaceDetailLegacyResult {
  String? area;
  String? city;
  String? district;
  String? formattedAddress;
  String? houseName;
  String? houseNumber;
  String? lat;
  String? lng;
  String? locality;
  String? pincode;
  String? poi;
  String? poiDist;
  String? state;
  String? street;
  String? streetDist;
  String? subDistrict;
  String? subLocality;
  String? subSubLocality;
  String? village;
  String? placeId;

  static PlaceDetailLegacyResult fromMap(Map<String, dynamic> map) {
    PlaceDetailLegacyResult resultsBean = PlaceDetailLegacyResult();
    resultsBean.area = map['area'];
    resultsBean.city = map['city'];
    resultsBean.district = map['district'];
    resultsBean.formattedAddress = map['formatted_address'];
    resultsBean.houseName = map['houseName'];
    resultsBean.houseNumber = map['houseNumber'];
    resultsBean.lat = map['lat'];
    resultsBean.lng = map['lng'];
    resultsBean.locality = map['locality'];
    resultsBean.pincode = map['pincode'];
    resultsBean.poi = map['poi'];
    resultsBean.poiDist = map['poi_dist'];
    resultsBean.state = map['state'];
    resultsBean.street = map['street'];
    resultsBean.streetDist = map['street_dist'];
    resultsBean.subDistrict = map['subDistrict'];
    resultsBean.subLocality = map['subLocality'];
    resultsBean.subSubLocality = map['subSubLocality'];
    resultsBean.village = map['village'];
    resultsBean.placeId = map['place_id'];
    return resultsBean;
  }

  Map toJson() => {
        "area": area,
        "city": city,
        "district": district,
        "formatted_address": formattedAddress,
        "houseName": houseName,
        "houseNumber": houseNumber,
        "lat": lat,
        "lng": lng,
        "locality": locality,
        "pincode": pincode,
        "poi": poi,
        "poi_dist": poiDist,
        "state": state,
        "street": street,
        "street_dist": streetDist,
        "subDistrict": subDistrict,
        "subLocality": subLocality,
        "subSubLocality": subSubLocality,
        "village": village,
        "place_id": placeId,
      };
}
